# poker_game_runner

Docker container: https://hub.docker.com/repository/docker/virtualsatai/poker_game_runner

Running: `docker run -it -v "C:\dev\poker_game_runner\student":/custom virtualsatai/poker_game_runner:0.0.1`